==> libnb-platform-java_6.5.orig.tar.gz: libnb-platform-java-6.5/core.windows/src/org/netbeans/core/windows/view/ui/toolbars/ResetToolbarsAction.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.core.windows.view.ui.toolbars;

import java.awt.event.ActionEvent;
import java.io.IOException;
import java.util.concurrent.Callable;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.AbstractAction;
import org.openide.awt.ToolbarPool;
import org.openide.filesystems.FileObject;
import org.openide.filesystems.FileSystem;
import org.openide.filesystems.Repository;
import org.openide.util.NbBundle;

/**
 *
 * @author S. Aubrecht
 */
public class ResetToolbarsAction extends AbstractAction {
    
    /** Creates a new instance of ResetToolbarsAction */
    public ResetToolbarsAction() {
        super( NbBundle.getMessage(ResetToolbarsAction.class, "CTL_ResetToolbarsAction") ); //NOI18N
    }

    public void actionPerformed(ActionEvent e) {
        String name = ToolbarPool.getDefault().getConfiguration();
        ToolbarConfiguration tbConf = ToolbarConfiguration.findConfiguration(name);
        if (tbConf != null) {
            try {
                //write the current config to disk first, removing it in the next
                //step will trigger toolbar rebuild
                tbConf.writeDocument();
            } catch( IOException ioE ) {
                Logger.getLogger(ResetToolbarsAction.class.getName()).log( Level.FINE, null, ioE );
            }
        }
        FileSystem fs = Repository.getDefault().getDefaultFileSystem();
        FileObject fo = fs.findResource( "Toolbars" ); //NOI18N
        Object attr = fo.getAttribute( "removeWritables" ); //NOI18N
        if( null != attr && attr instanceof Callable ) {
            try {
                ((Callable)attr).call();
            } catch (Exception ex) {
                Logger.getLogger(ResetToolbarsAction.class.getName()).log( Level.FINE, null, ex );
            }
        }
        ToolbarConfiguration.resetToolbarIconSize();
        ToolbarPool.getDefault().setConfiguration("Standard");
    }
    
}

==> libnb-platform-java_6.8.orig.tar.gz: libnb-platform-java-6.8/core.windows/src/org/netbeans/core/windows/view/ui/toolbars/ResetToolbarsAction.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.core.windows.view.ui.toolbars;

import java.awt.event.ActionEvent;
import java.util.concurrent.Callable;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.AbstractAction;
import org.openide.awt.ToolbarPool;
import org.openide.filesystems.FileObject;
import org.openide.filesystems.FileUtil;
import org.openide.util.NbBundle;

/**
 *
 * @author S. Aubrecht
 */
public class ResetToolbarsAction extends AbstractAction {
    
    /** Creates a new instance of ResetToolbarsAction */
    public ResetToolbarsAction() {
        super( NbBundle.getMessage(ResetToolbarsAction.class, "CTL_ResetToolbarsAction") ); //NOI18N
    }

    public void actionPerformed(ActionEvent e) {
        String name = ToolbarPool.getDefault().getConfiguration();
        FileObject fo = FileUtil.getConfigFile( "Toolbars" ); //NOI18N
        Object attr = fo.getAttribute( "removeWritables" ); //NOI18N
        if( null != attr && attr instanceof Callable ) {
            try {
                ((Callable)attr).call();
            } catch (Exception ex) {
                Logger.getLogger(ResetToolbarsAction.class.getName()).log( Level.FINE, null, ex );
            }
        }
        ToolbarPool.getDefault().waitFinished();
        ToolbarPool.getDefault().setConfiguration(name);
    }
    
}
